==> haskell-fast-logger-3.1.2-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fast-logger
version:              3.1.2
visibility:           public
id:                   fast-logger-3.1.2-HRfTVNlQd84GlAKlGtHEjK
key:                  fast-logger-3.1.2-HRfTVNlQd84GlAKlGtHEjK
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  83dc4f677234c7cbcba3707686fb13cb
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.IO
    System.Log.FastLogger.FileIO System.Log.FastLogger.LogStr
    System.Log.FastLogger.Logger

import-dirs:          /usr/lib/ghc-9.2.8/site-local/fast-logger-3.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fast-logger-3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.1.2-HRfTVNlQd84GlAKlGtHEjK
depends:
    array-0.5.4.0 auto-update-0.1.6-FEvmDo0AWcQJmIw0TZahhm
    base-4.16.4.0 bytestring-0.11.4.0 directory-1.3.6.2
    easy-file-0.2.5-3SNkbcvaaR88qrUKOQKENH filepath-1.4.2.2
    text-1.2.5.0 unix-compat-0.7.2-GF6nRFHS9lJCc08eWtx5Md
    unix-time-0.4.15-BU1Gvu6zYZQCaU1GisuzaF

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.1.2-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fast-logger
version:              3.1.2
visibility:           public
id:                   fast-logger-3.1.2-40jgXSfrrv1Lb3em5mDBkP
key:                  fast-logger-3.1.2-40jgXSfrrv1Lb3em5mDBkP
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  25dca324f237b560ea377663ffc5e665
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.IO
    System.Log.FastLogger.FileIO System.Log.FastLogger.LogStr
    System.Log.FastLogger.Logger

import-dirs:          /usr/lib/ghc-9.2.8/site-local/fast-logger-3.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fast-logger-3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.1.2-40jgXSfrrv1Lb3em5mDBkP
depends:
    array-0.5.4.0 auto-update-0.1.6-A7duhPyDH8qMEay0dnF6K base-4.16.4.0
    bytestring-0.11.4.0 directory-1.3.6.2
    easy-file-0.2.5-3BrUsBFJO1mFoiDf3b4x8H filepath-1.4.2.2
    text-1.2.5.0 unix-compat-0.7.2-Kcmk3eldTBQKVrrJpCSKjS
    unix-time-0.4.15-BrarRkEoGVFCjMK11KrzsA

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
